<!DOCTYPE html
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/">
<head>
  <title>${request.path_info}</title>
  <style type="text/css">
    dd {
    position: relative;
    }

    dt { 
    float: left;
    clear: left;
    font-weight: bold;
    margin-right: 0.5em;      
    }    
    
    dl { 
    position: relative;
    } 

  </style>
</head>
<body>
  <div class="section" py:for="section in sorted(sections)">
    <h1>[${section}]</h1>
    <dl>
      <py:for each="key, value in sorted(sections[section].items())">
        <dt>${key}</dt> : 
        <dd>${value}</dd>
      </py:for>
    </dl>
  </div>
</body>
</html>
