<!DOCTYPE html
    PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml"
      xmlns:py="http://genshi.edgewall.org/">
<head>
  <title>${request.path_info}</title>
</head>
<body>
  <h1>${request.path_info}</h1>
  <ul>
    <li py:for="item in sorted(items)">
      <a href="${request.path_info.rstrip('/')}/${item}">${item}</a>
    </li>
  </ul>
</body>
</html>
